System.register(['./generated-dep4-effect.js'], (function () {
	'use strict';
	return {
		setters: [null],
		execute: (function () {

			console.log('main3');

		})
	};
}));
